..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


============
 Invenio v3
============

**Open Source framework for large-scale digital repositories.**

.. image:: https://img.shields.io/pypi/v/invenio.svg
    :target: https://pypi.org/project/invenio/

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio.svg
    :target: https://github.com/inveniosoftware/invenio/blob/master/LICENSE

.. image:: https://travis-ci.org/inveniosoftware/invenio.svg?branch=master
    :target: https://travis-ci.org/inveniosoftware/invenio

.. image:: https://badges.gitter.im/Join%20Chat.svg
    :target: https://gitter.im/inveniosoftware/invenio

Invenio is like a Swiss Army knife of battle-tested, safe and secure modules
providing you with all the features you need to run a trusted digital
repository.
